# -*- coding:utf-8 -*-
from tiger_notebook.component_drill.drill.base_drill import BaseDrill
from tiger_notebook.component_drill.drill.python_single_drill import PythonSingleDrill
from tiger_notebook.component_drill.drill.aistudio_argo_drill import AistudioArgoDrill
from tiger_notebook.component_drill.drill.sample_train_drill import SampleTrainDrill
